==> qmmp_1.2.6.orig.tar.bz2: qmmp-1.2.6/src/app/translations/qmmp_sk.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="sk">
<context>
    <name>BuiltinCommandLineOption</name>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="82"/>
        <source>Skip forward in playlist</source>
        <translation>Posunúť sa v plaliste</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="83"/>
        <source>Skip backwards in playlist</source>
        <translation>Vrátiť sa v playliste</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="72"/>
        <source>Start playing current song</source>
        <translation>Začať prehrávanie súčasnej piesne</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="71"/>
        <source>Don&apos;t clear the playlist</source>
        <translation>Nevyčisťovať playlist</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="73"/>
        <source>Pause current song</source>
        <translation>Pozastaviť súčasnú pieseň</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="74"/>
        <source>Pause if playing, play otherwise</source>
        <translation>Pozastaviť ak hrá, inak hrať</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="75"/>
        <source>Stop current song</source>
        <translation>Zastaviť súčasnú pieseň</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="76"/>
        <source>Display Jump to File dialog</source>
        <translation>Zobraziť dialóg Preskočiť na súbor</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="77"/>
        <source>Quit application</source>
        <translation>Ukončiť program</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="78"/>
        <source>Set playback volume (example: qmmp --volume 20)</source>
        <translation>Nastaviť hlasitosť prehrávania (napríklad: qmmp --volume 20)</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="79"/>
        <source>Print volume level</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="80"/>
        <source>Mute/Restore volume</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="81"/>
        <source>Print mute status</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="84"/>
        <source>Show/hide application</source>
        <translation>Zobraziť/skryť program</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="85"/>
        <source>Show main window</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="86"/>
        <source>Display Add File dialog</source>
        <translation>Zobraziť dialóg Pridať súbor</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="87"/>
        <source>Display Add Directory dialog</source>
        <translation>Zobraziť dialóg Pridať priečinok</translation>
    </message>
</context>
<context>
    <name>QMMPStarter</name>
    <message>
        <location filename="../qmmpstarter.cpp" line="373"/>
        <source>Usage: qmmp [options] [files]</source>
        <translation>Použitie: qmmp [možnosti] [súbory]</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="374"/>
        <source>Options:</source>
        <translation>Možnosti:</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="380"/>
        <source>Start qmmp with the specified user interface</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="381"/>
        <source>List all available user interfaces</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="382"/>
        <source>Don&apos;t start the application</source>
        <translation>Nezapnúť program</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="384"/>
        <source>Print version number and exit</source>
        <translation>Vypísať číslo verzie a skončiť</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="386"/>
        <source>Home page: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="387"/>
        <source>Development page: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="388"/>
        <source>Bug tracker: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="393"/>
        <source>Command Line Help</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="406"/>
        <source>QMMP version: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="407"/>
        <source>Compiled with Qt version: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="408"/>
        <source>Using Qt version: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="411"/>
        <source>Qmmp Version</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="428"/>
        <source>User Interfaces</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="383"/>
        <source>Display this text and exit</source>
        <translation>Zobraziť tento text a skončiť</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="109"/>
        <source>Unknown command</source>
        <translation>Neznámý príkaz</translation>
    </message>
</context>
</TS>

==> qmmp_1.3.1.orig.tar.bz2: qmmp-1.3.1/src/app/translations/qmmp_sk.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sk">
<context>
    <name>BuiltinCommandLineOption</name>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="71"/>
        <source>Don&apos;t clear the playlist</source>
        <translation>Nevyčisťovať playlist</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="72"/>
        <source>Start playing current song</source>
        <translation>Začať prehrávanie súčasnej piesne</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="73"/>
        <source>Pause current song</source>
        <translation>Pozastaviť súčasnú pieseň</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="74"/>
        <source>Pause if playing, play otherwise</source>
        <translation>Pozastaviť ak hrá, inak hrať</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="75"/>
        <source>Stop current song</source>
        <translation>Zastaviť súčasnú pieseň</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="76"/>
        <source>Display Jump to File dialog</source>
        <translation>Zobraziť dialóg Preskočiť na súbor</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="77"/>
        <source>Quit application</source>
        <translation>Ukončiť program</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="78"/>
        <source>Set playback volume (example: qmmp --volume 20)</source>
        <translation>Nastaviť hlasitosť prehrávania (napríklad: qmmp --volume 20)</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="79"/>
        <source>Print volume level</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="80"/>
        <source>Mute/Restore volume</source>
        <translation>Vypnúť/obnoviť zvuk</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="81"/>
        <source>Print mute status</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="82"/>
        <source>Skip forward in playlist</source>
        <translation>Posunúť sa v plaliste</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="83"/>
        <source>Skip backwards in playlist</source>
        <translation>Vrátiť sa v playliste</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="84"/>
        <source>Show/hide application</source>
        <translation>Zobraziť/skryť program</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="85"/>
        <source>Show main window</source>
        <translation>Zobraziť hlavné okno</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="86"/>
        <source>Display Add File dialog</source>
        <translation>Zobraziť dialóg Pridať súbor</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="87"/>
        <source>Display Add Directory dialog</source>
        <translation>Zobraziť dialóg Pridať priečinok</translation>
    </message>
</context>
<context>
    <name>QMMPStarter</name>
    <message>
        <location filename="../qmmpstarter.cpp" line="113"/>
        <source>Unknown command</source>
        <translation>Neznámý príkaz</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="413"/>
        <source>Usage: qmmp [options] [files]</source>
        <translation>Použitie: qmmp [možnosti] [súbory]</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="414"/>
        <source>Options:</source>
        <translation>Možnosti:</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="420"/>
        <source>Start qmmp with the specified user interface</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="421"/>
        <source>List all available user interfaces</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="422"/>
        <source>Don&apos;t start the application</source>
        <translation>Nezapnúť program</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="423"/>
        <source>Display this text and exit</source>
        <translation>Zobraziť tento text a skončiť</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="424"/>
        <source>Print version number and exit</source>
        <translation>Vypísať číslo verzie a skončiť</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="426"/>
        <source>Home page: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="427"/>
        <source>Development page: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="428"/>
        <source>Bug tracker: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="135"/>
        <location filename="../qmmpstarter.cpp" line="433"/>
        <source>Command Line Help</source>
        <translation>Nápoveda príkazového riadka</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="446"/>
        <source>QMMP version: %1</source>
        <translation>Verzia QMMP: %1</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="447"/>
        <source>Compiled with Qt version: %1</source>
        <translation>Skompilované s verziou Qt: %1</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="448"/>
        <source>Using Qt version: %1</source>
        <translation>Používaná verzia Qt: %1</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="451"/>
        <source>Qmmp Version</source>
        <translation>Verzia Qmmp</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="468"/>
        <source>User Interfaces</source>
        <translation>Užívateľské rozhrania</translation>
    </message>
</context>
</TS>
